# Flask-Mailman

Flask-Mailman is a Flask extension providing simple email sending capabilities.

It was meant to replace unmaintained Flask-Mail with better warranty and more features.

## Usage

Flask-Mail ported Django's email implementation to your Flask applications, it's maybe the best mail sending implementation that's available for python.

The way of using this extension is almost the same as Flask-Mail and Django.

You can just read their documentation and choose your prefer style.

Django documentation: https://docs.djangoproject.com/en/2.2/topics/email/

Flask-Mail documentation: http://packages.python.org/Flask-Mail